package com.onsiteservice.admin.controller.order;

import com.onsiteservice.admin.controller.order.dto.OrderPageDTO;
import com.onsiteservice.admin.controller.order.vo.OrderDetailVO;
import com.onsiteservice.admin.controller.order.vo.OrderPageVO;
import com.onsiteservice.admin.service.order.AdminOrderService;
import com.onsiteservice.common.annotation.dict.Dict;
import com.onsiteservice.entity.order.ServiceOrder;

import com.onsiteservice.core.result.Result;
import com.onsiteservice.dao.common.page.PageInfoVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.NonNull;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.annotation.Resource;
import javax.validation.constraints.Positive;

import static com.onsiteservice.core.result.ResultGenerator.success;

/**
 * @author 商天翔
 * @date 2022-07-14 15:11
 * @description ServiceOrderController控制类
 */
@ApiIgnore
@Api(tags = "ServiceOrderController")
@RestController
@RequestMapping("/order")
@Validated
public class ServiceOrderController {

    @Resource
    private AdminOrderService adminOrderService;

    @Dict(code = "BIZ0002", name = "orderStatus")
    @ApiOperation(value = "分页查询列表", notes = "作者: 商天翔")
    @PostMapping("/page")
    public Result<PageInfoVO<OrderPageVO>> getPage(@RequestBody @NonNull @Validated OrderPageDTO param) {
        return success(adminOrderService.getPage(param), "获取分页列表");
    }

    @ApiOperation(value = "根据id查询", notes = "作者: 商天翔")
    @GetMapping("/{id}")
    public Result<OrderDetailVO> getDetails(@PathVariable @Positive Long id) {
        return success(adminOrderService.getOrderDetail(id));
    }

}
